pub struct InlineResponseDefault {
pub merkle: Vec<String>,
pub block_height: f32,
pub pos: f32,
}Fields
merkle: Vec<String>A list of transaction hashes the current hash is paired with, deepest pairing first.
block_height: f32The height of the block the transaction was confirmed in.
pos: f32The 0-based index of the position of the transaction in the ordered list of transactions in the block.
Implementations